﻿//-----------------------------------------------------------------------
// <copyright file="ConfigPrint.cs" company="Tigerware Development">
//     Copyright(c) Tigerware Development. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Printing;
using System.Text;
using System.Windows.Forms;

namespace ElexolIO24PTU.Net
{
    public partial class ConfigPrint : Form
    {
        private byte[] _EEVal;
        private int _page_count = 0;

        public ConfigPrint()
        {
            InitializeComponent();
        }

        public void Print(byte[] EEVal)
        {
            _EEVal = EEVal;
            PrintDocument pd = createDocument();
            pd.Print();
        }

        public void Preview(byte[] EEVal)
        {
            _EEVal = EEVal;
            PrintDocument pd = createDocument();
            printPreviewControl1.Document = pd;
            this.ShowDialog();
        }

        private PrintDocument createDocument()
        {
            PrintDocument pd = new PrintDocument();
            pd.BeginPrint += new PrintEventHandler(pd_BeginPrint);
            pd.PrintPage += new PrintPageEventHandler(pd_PrintPage);
            return pd;
        }

        private string valueToString(byte value, string chars)
        {
            string text = string.Format("{0} {1} {2} {3} {4} {5} {6} {7}  {8}  {9}",
                (value & 128) == 0 ? chars[0] : chars[1],
                (value & 64) == 0 ? chars[0] : chars[1],
                (value & 32) == 0 ? chars[0] : chars[1],
                (value & 16) == 0 ? chars[0] : chars[1],
                (value & 8) == 0 ? chars[0] : chars[1],
                (value & 4) == 0 ? chars[0] : chars[1],
                (value & 2) == 0 ? chars[0] : chars[1],
                (value & 1) == 0 ? chars[0] : chars[1],
                value.ToString("X2"), value);

            return text;
        }

        void pd_BeginPrint(object sender, PrintEventArgs e)
        {
            _page_count = 0;
        }

        void pd_PrintPage(object sender, PrintPageEventArgs e)
        {
            float leftMargin = e.MarginBounds.Left;
            float topMargin = e.MarginBounds.Top;

            Font headerFont = new Font(FontFamily.GenericMonospace, 12);
            Font printFont = new Font(FontFamily.GenericMonospace, 15);
            Font printFontBold = new Font(printFont, FontStyle.Bold);
            float fontHeight = printFont.GetHeight(e.Graphics);

            // print the date
            e.Graphics.DrawString(string.Format("{0} {1}", DateTime.Now.ToShortDateString(), DateTime.Now.ToShortTimeString()),
                headerFont, Brushes.Black,leftMargin, topMargin);

            e.Graphics.DrawLine(Pens.Black, leftMargin, topMargin + 25, e.MarginBounds.Right, topMargin + 25);

            // Fixed IP Settings
            int col1 = (int)leftMargin, col2 = 350, col3 = 575, col4 = 650;
            e.Graphics.DrawString("Fixed IP Address", printFont, Brushes.Black, col1, topMargin + 35);
            e.Graphics.DrawString("IP Address", printFont, Brushes.Black, col1, topMargin + 60);
            e.Graphics.DrawString("Port", printFont, Brushes.Black, col3, topMargin + 60);
            e.Graphics.DrawString("Subnet Mask", printFont, Brushes.Black, col1, topMargin + 85);
            e.Graphics.DrawString("Default Gateway", printFont, Brushes.Black, col1, topMargin + 110);

            e.Graphics.DrawString((_EEVal[10] & 1) == 0 ? "Disabled" : "Enabled",
                printFontBold, Brushes.Black, col2, topMargin + 35);
            e.Graphics.DrawString(string.Format("{0}.{1}.{2}.{3}", _EEVal[12], _EEVal[13], _EEVal[14], _EEVal[15]),
                printFontBold, Brushes.Black, col2, topMargin + 60);
            e.Graphics.DrawString((_EEVal[59] * 256 + _EEVal[58]).ToString(),
                printFontBold, Brushes.Black, col4, topMargin + 60);
            e.Graphics.DrawString(string.Format("{0}.{1}.{2}.{3}", _EEVal[50], _EEVal[51], _EEVal[52], _EEVal[53]),
                printFontBold, Brushes.Black, col2, topMargin + 85);
            e.Graphics.DrawString(string.Format("{0}.{1}.{2}.{3}", _EEVal[54], _EEVal[55], _EEVal[56], _EEVal[57]),
                printFontBold, Brushes.Black, col2, topMargin + 110);

            // Powerup Settings
            e.Graphics.DrawString("Power-Up Settings", printFont, Brushes.Black, col1, topMargin + 160);
            e.Graphics.DrawString((_EEVal[10] & 2) == 0 ? "Disabled" : "Enabled",
                printFontBold, Brushes.Black, col2, topMargin + 160);

            // labels
            e.Graphics.DrawString("Bits             Hex Decimal", printFont, Brushes.Black, col2, topMargin + 185);
            e.Graphics.DrawString("Value Port A", printFont, Brushes.Black, col1, topMargin + 210);
            e.Graphics.DrawString("Value Port B", printFont, Brushes.Black, col1, topMargin + 235);
            e.Graphics.DrawString("Value Port C", printFont, Brushes.Black, col1, topMargin + 260);

            e.Graphics.DrawString("Direction Port A", printFont, Brushes.Black, col1, topMargin + 310);
            e.Graphics.DrawString("Direction Port B", printFont, Brushes.Black, col1, topMargin + 335);
            e.Graphics.DrawString("Direction Port C", printFont, Brushes.Black, col1, topMargin + 360);

            e.Graphics.DrawString("Pull-Up Port A", printFont, Brushes.Black, col1, topMargin + 410);
            e.Graphics.DrawString("Pull-Up Port B", printFont, Brushes.Black, col1, topMargin + 435);
            e.Graphics.DrawString("Pull-Up Port C", printFont, Brushes.Black, col1, topMargin + 460);

            e.Graphics.DrawString("Threshold Port A", printFont, Brushes.Black, col1, topMargin + 510);
            e.Graphics.DrawString("Threshold Port B", printFont, Brushes.Black, col1, topMargin + 535);
            e.Graphics.DrawString("Threshold Port C", printFont, Brushes.Black, col1, topMargin + 560);

            e.Graphics.DrawString("Schmitt Port A", printFont, Brushes.Black, col1, topMargin + 610);
            e.Graphics.DrawString("Schmitt Port B", printFont, Brushes.Black, col1, topMargin + 635);
            e.Graphics.DrawString("Schmitt Port C", printFont, Brushes.Black, col1, topMargin + 660);

            // values
            e.Graphics.DrawString(valueToString(_EEVal[17], "01"), printFontBold, Brushes.Black, col2, topMargin + 210);
            e.Graphics.DrawString(valueToString(_EEVal[22], "01"), printFontBold, Brushes.Black, col2, topMargin + 235);
            e.Graphics.DrawString(valueToString(_EEVal[27], "01"), printFontBold, Brushes.Black, col2, topMargin + 260);

            e.Graphics.DrawString(valueToString(_EEVal[16], "OI"), printFontBold, Brushes.Black, col2, topMargin + 310);
            e.Graphics.DrawString(valueToString(_EEVal[21], "OI"), printFontBold, Brushes.Black, col2, topMargin + 335);
            e.Graphics.DrawString(valueToString(_EEVal[26], "OI"), printFontBold, Brushes.Black, col2, topMargin + 360);

            e.Graphics.DrawString(valueToString(_EEVal[19], "YN"), printFontBold, Brushes.Black, col2, topMargin + 410);
            e.Graphics.DrawString(valueToString(_EEVal[24], "YN"), printFontBold, Brushes.Black, col2, topMargin + 435);
            e.Graphics.DrawString(valueToString(_EEVal[29], "YN"), printFontBold, Brushes.Black, col2, topMargin + 460);

            e.Graphics.DrawString(valueToString(_EEVal[18], "CT"), printFontBold, Brushes.Black, col2, topMargin + 510);
            e.Graphics.DrawString(valueToString(_EEVal[23], "CT"), printFontBold, Brushes.Black, col2, topMargin + 535);
            e.Graphics.DrawString(valueToString(_EEVal[28], "CT"), printFontBold, Brushes.Black, col2, topMargin + 560);

            e.Graphics.DrawString(valueToString(_EEVal[20], "SN"), printFontBold, Brushes.Black, col2, topMargin + 610);
            e.Graphics.DrawString(valueToString(_EEVal[25], "SN"), printFontBold, Brushes.Black, col2, topMargin + 635);
            e.Graphics.DrawString(valueToString(_EEVal[30], "SN"), printFontBold, Brushes.Black, col2, topMargin + 660);

            // autoscan
            e.Graphics.DrawString("AutoScan", printFont, Brushes.Black, col1, topMargin + 710);
            e.Graphics.DrawString((_EEVal[10] & 4) == 0 ? "Disabled" : "Enabled",
                printFontBold, Brushes.Black, col2, topMargin + 710);

            // labels
            e.Graphics.DrawString("Bits             Hex Decimal", printFont, Brushes.Black, col2, topMargin + 735);
            e.Graphics.DrawString("Bit Test Port A", printFont, Brushes.Black, col1, topMargin + 760);
            e.Graphics.DrawString("Bit Test Port B", printFont, Brushes.Black, col1, topMargin + 785);
            e.Graphics.DrawString("Bit Test Port C", printFont, Brushes.Black, col1, topMargin + 810);
            e.Graphics.DrawString("Scan Period", printFont, Brushes.Black, col1, topMargin + 835);
            e.Graphics.DrawString("Filter Count", printFont, Brushes.Black, col1, topMargin + 860);
            e.Graphics.DrawString("Target IP Address", printFont, Brushes.Black, col1, topMargin + 885);
            e.Graphics.DrawString("Port", printFont, Brushes.Black, col3, topMargin + 885);
            e.Graphics.DrawString("MAC Address", printFont, Brushes.Black, col1, topMargin + 910);

            // values
            e.Graphics.DrawString(valueToString(_EEVal[32], "01"), printFontBold, Brushes.Black, col2, topMargin + 760);
            e.Graphics.DrawString(valueToString(_EEVal[33], "01"), printFontBold, Brushes.Black, col2, topMargin + 785);
            e.Graphics.DrawString(valueToString(_EEVal[34], "01"), printFontBold, Brushes.Black, col2, topMargin + 810);
            e.Graphics.DrawString(_EEVal[35].ToString(), printFontBold, Brushes.Black, col2, topMargin + 835);
            e.Graphics.DrawString((_EEVal[37] * 256 + _EEVal[36]).ToString(), printFontBold, Brushes.Black, col2, topMargin + 860);
            e.Graphics.DrawString(string.Format("{0}.{1}.{2}.{3}", _EEVal[44], _EEVal[45], _EEVal[46], _EEVal[47]),
                printFontBold, Brushes.Black, col2, topMargin + 885);
            e.Graphics.DrawString((_EEVal[49] * 256 + _EEVal[48]).ToString(),
                printFontBold, Brushes.Black, col4, topMargin + 885);
            e.Graphics.DrawString(string.Format("{0}:{1}:{2}:{3}:{4}:{5}", _EEVal[38].ToString("X2"), _EEVal[39].ToString("X2"), _EEVal[40].ToString("X2"), _EEVal[41].ToString("X2"), _EEVal[42].ToString("X2"), _EEVal[43].ToString("X2")),
                printFontBold, Brushes.Black, col2, topMargin + 910);

            // footer
            e.Graphics.DrawLine(Pens.Black, leftMargin, topMargin + 960, e.MarginBounds.Right, topMargin + 960);

            string footer = string.Format("Page {0}", ++_page_count);
            SizeF footerSize = e.Graphics.MeasureString(footer, headerFont);
            e.Graphics.DrawString(footer, headerFont, Brushes.Black, e.MarginBounds.Right - footerSize.Width, topMargin + 970);
        }

        private void tsbExit_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void tsbPrint_Click(object sender, EventArgs e)
        {
            printPreviewControl1.Document.Print();
        }
    }
}
